@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2010 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -32,6 +32,8 @@
 #include "quote.h"
 #include "socket.h"
 
+#include <mpd/socket.h>
+
 #include <assert.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -55,7 +57,7 @@ closesocket(int fd)
 #endif
 
 struct mpd_async {
-	int fd;
+	mpd_socket_t fd;
 
 	struct mpd_error_info error;
 
@@ -69,7 +71,7 @@ mpd_async_new(int fd)
 {
 	struct mpd_async *async;
 
-	assert(fd >= 0);
+	assert(fd != MPD_INVALID_SOCKET);
 
 	async = malloc(sizeof(*async));
 	if (async == NULL)
@@ -132,11 +134,21 @@ int
 mpd_async_get_fd(const struct mpd_async *async)
 {
 	assert(async != NULL);
-	assert(async->fd >= 0);
+	assert(async->fd != MPD_INVALID_SOCKET);
 
 	return async->fd;
 }
 
+void
+mpd_async_set_keepalive(struct mpd_async *async,
+			bool keepalive)
+{
+	assert(async != NULL);
+	assert(async->fd != MPD_INVALID_SOCKET);
+
+	mpd_socket_keepalive(async->fd, keepalive);
+}
+
 enum mpd_async_event
 mpd_async_events(const struct mpd_async *async)
 {
@@ -180,7 +192,7 @@ mpd_async_read(struct mpd_async *async)
 	ssize_t nbytes;
 
 	assert(async != NULL);
-	assert(async->fd >= 0);
+	assert(async->fd != MPD_INVALID_SOCKET);
 	assert(!mpd_error_is_defined(&async->error));
 
 	room = mpd_buffer_room(&async->input);
@@ -217,7 +229,7 @@ mpd_async_write(struct mpd_async *async)
 	ssize_t nbytes;
 
 	assert(async != NULL);
-	assert(async->fd >= 0);
+	assert(async->fd != MPD_INVALID_SOCKET);
 	assert(!mpd_error_is_defined(&async->error));
 
 	size = mpd_buffer_size(&async->output);
