@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2010 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -43,6 +43,7 @@
 #else
 #  include <netinet/in.h>
 #  include <arpa/inet.h>
+#  include <sys/select.h>
 #  include <sys/socket.h>
 #  include <netdb.h>
 #  include <sys/un.h>
@@ -85,7 +86,7 @@ mpd_socket_global_init(struct mpd_error_info *error)
 #endif
 
 /**
- * Wait for the socket to become readable.
+ * Wait for the socket to become writable.
  */
 static int
 mpd_socket_wait(unsigned fd, struct timeval *tv)
@@ -111,7 +112,7 @@ mpd_socket_wait(unsigned fd, struct timeval *tv)
  * on success, 0 on timeout, -errno on error.
  */
 static int
-mpd_socket_wait_connected(int fd, struct timeval *tv)
+mpd_socket_wait_connected(mpd_socket_t fd, struct timeval *tv)
 {
 	int ret;
 	int s_err = 0;
@@ -132,14 +133,14 @@ mpd_socket_wait_connected(int fd, struct timeval *tv)
 	return 1;
 }
 
-int
+mpd_socket_t
 mpd_socket_connect(const char *host, unsigned port, const struct timeval *tv0,
 		   struct mpd_error_info *error)
 {
 	struct timeval tv = *tv0;
 	struct resolver *resolver;
 	const struct resolver_address *address;
-	int fd, ret;
+	int ret;
 
 	resolver = resolver_new(host, port);
 	if (resolver == NULL) {
@@ -151,9 +152,10 @@ mpd_socket_connect(const char *host, unsigned port, const struct timeval *tv0,
 	assert(!mpd_error_is_defined(error));
 
 	while ((address = resolver_next(resolver)) != NULL) {
-		fd = socket_cloexec_nonblock(address->family, SOCK_STREAM,
-					     address->protocol);
-		if (fd < 0) {
+		mpd_socket_t fd = socket_cloexec_nonblock(address->family,
+							  SOCK_STREAM,
+							  address->protocol);
+		if (fd == MPD_INVALID_SOCKET) {
 			mpd_error_clear(error);
 			mpd_error_errno(error);
 			continue;
@@ -206,3 +208,13 @@ mpd_socket_close(int fd)
 	return closesocket(fd);
 #endif
 }
+
+void
+mpd_socket_keepalive(int fd, bool keepalive)
+{
+	int keepalive_i = keepalive;
+
+
+	(void) setsockopt(fd, SOL_SOCKET, SO_KEEPALIVE,
+			  (const char *) &keepalive_i, sizeof keepalive_i);
+}
