@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2010 The Music Player Daemon Project
+   (c) 2003-2017 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -164,6 +164,9 @@ print_song(const struct mpd_song *song)
 	if (mpd_song_get_duration(song) > 0)
 		LOG_INFO("time: %i", mpd_song_get_duration(song));
 
+	if (mpd_song_get_duration_ms(song) > 0)
+		LOG_INFO("duration: %i", mpd_song_get_duration_ms(song));
+
 	LOG_INFO("pos: %u", mpd_song_get_pos(song));
 }
 
